@@ -77,7 +77,8 @@ from ecs_composex.ecs.docker_tools import find_closest_fargate_configuration
 from ecs_composex.ecs.ecs_aws_sidecars import define_xray_container
 from ecs_composex.ecs.ecs_conditions import USE_HOSTNAME_CON_T
 from ecs_composex.ecs.ecs_container import Container
-from ecs_composex.ecs.ecs_iam import add_service_roles
+from ecs_composex.ecs.ecs_container_config import import_secrets
+from ecs_composex.ecs.ecs_iam import add_service_roles, expand_role_polices
 from ecs_composex.ecs.ecs_params import NETWORK_MODE, EXEC_ROLE_T, TASK_ROLE_T, TASK_T
 from ecs_composex.ecs.ecs_params import SERVICE_NAME, SERVICE_HOSTNAME
 from ecs_composex.ecs.ecs_params import (
@@ -170,16 +171,17 @@ class Task(object):
     Class to handle the Task definition building and parsing along with the service config.
     """
 
-    def __init__(self, template, containers_config, family_parameters):
+    def __init__(self, template, containers_config, family_parameters, settings):
         """
         Init method
         """
+        add_service_roles(template)
         self.family_config = None
         self.containers = []
         self.containers_config = containers_config
         self.stack_parameters = {}
-        self.sort_container_configs(template, containers_config)
-        add_service_roles(template, self.family_config)
+        self.sort_container_configs(template, containers_config, settings)
+        expand_role_polices(template, self.family_config)
         if self.family_config.use_xray:
             self.containers.append(define_xray_container())
             add_parameters(template, [ecs_params.XRAY_IMAGE])
@@ -214,7 +216,7 @@ class Task(object):
             ),
         )
 
-    def sort_container_configs(self, template, containers_config):
+    def sort_container_configs(self, template, containers_config, settings):
         """
         Method to sort out the containers dependencies and create the containers definitions based on the configs.
         :return:
@@ -237,6 +239,9 @@ class Task(object):
                 service_config["definition"],
                 service_config["config"],
             )
+            import_secrets(
+                template, service_config["definition"], container.definition, settings
+            )
             self.containers.append(container.definition)
             self.stack_parameters.update(container.stack_parameters)
             if self.family_config is None:
